package Alien::ffmpeg;
our $AUTHORITY = 'cpan:GETTY';
# ABSTRACT: Easy installation of ffmpeg
$Alien::ffmpeg::VERSION = '0.104';
use parent 'Alien::Base';

1;

__END__

=pod

=head1 NAME

Alien::ffmpeg - Easy installation of ffmpeg

=head1 VERSION

version 0.104

=head1 AUTHOR

Torsten Raudssus <torsten@raudss.us>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
